@@ -1,9 +1,9 @@
 package Acme::CPANModules::Sudoku;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-12'; # DATE
+our $DATE = '2021-01-13'; # DATE
 our $DIST = 'Acme-CPANModules-Sudoku'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -14,12 +14,17 @@ Recently (Dec 2020) I picked up more interest in Sudoku, as I was spending more
 time at home with the kids, and there was a book of Sudoku puzzles lying around
 in the room.
 
-There are certainly more modules on CPAN for solving Sudoku puzzles compared to
-modules/scripts that let you play Sudoku. Basically, I find that there's no good
-playable Sudoku game on CPAN.
-
 **Playing**
 
+There are certainly more modules on CPAN for solving Sudoku puzzles compared to
+for playing. And between the two available modules, I find that there's no good
+playable Sudoku game on CPAN. You'd be better off opening your browser and visit
+<https://websudoku.com> or <https://sudoku.com>. Sad but true. Not the case for
+all games though. I did enjoy *Games::FrozenBubble* and still play *Games::2048*
+from time to time.
+
+These modules are for playing Sudoku:
+
 <pm:Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
 really convenient to play unless you're a CLI freak.
 
@@ -31,14 +36,14 @@ boxes.
 **Generating**
 
 These modules can generate Sudoku puzzles for you, though not let you
-interactively play/solve them.
+interactively play/solve them:
 
 <pm:Spreadsheet::HTML::Presets::Sudoku>
 
 
 **Solving**
 
-There's no shortage of modules written to solve Sudoku puzzles. I plan to
+There is no shortage of modules written to solve Sudoku puzzles. I plan to
 benchmark these but for now here's the list:
 
 <pm:Games::Sudoku::Lite>
@@ -82,7 +87,7 @@ Acme::CPANModules::Sudoku - Sudoku-related modules on CPAN
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::Sudoku (from Perl distribution Acme-CPANModules-Sudoku), released on 2021-01-12.
+This document describes version 0.003 of Acme::CPANModules::Sudoku (from Perl distribution Acme-CPANModules-Sudoku), released on 2021-01-13.
 
 =head1 DESCRIPTION
 
@@ -90,12 +95,17 @@ Recently (Dec 2020) I picked up more interest in Sudoku, as I was spending more
 time at home with the kids, and there was a book of Sudoku puzzles lying around
 in the room.
 
-There are certainly more modules on CPAN for solving Sudoku puzzles compared to
-modules/scripts that let you play Sudoku. Basically, I find that there's no good
-playable Sudoku game on CPAN.
-
 B<Playing>
 
+There are certainly more modules on CPAN for solving Sudoku puzzles compared to
+for playing. And between the two available modules, I find that there's no good
+playable Sudoku game on CPAN. You'd be better off opening your browser and visit
+L<https://websudoku.com> or L<https://sudoku.com>. Sad but true. Not the case for
+all games though. I did enjoy I<Games::FrozenBubble> and still play I<Games::2048>
+from time to time.
+
+These modules are for playing Sudoku:
+
 L<Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
 really convenient to play unless you're a CLI freak.
 
@@ -106,13 +116,13 @@ boxes.
 B<Generating>
 
 These modules can generate Sudoku puzzles for you, though not let you
-interactively play/solve them.
+interactively play/solve them:
 
 L<Spreadsheet::HTML::Presets::Sudoku>
 
 B<Solving>
 
-There's no shortage of modules written to solve Sudoku puzzles. I plan to
+There is no shortage of modules written to solve Sudoku puzzles. I plan to
 benchmark these but for now here's the list:
 
 L<Games::Sudoku::Lite>
